<template>
  <div class="policy-page">
    <!-- Header -->
    <header class="policy-header bg-white shadow-sm py-3 sticky-top">
      <div class="container-fluid">
        <div class="d-flex align-items-center justify-content-between">
          <nuxt-link to="/" class="text-default fs-4">
            <i class="icon icon-regular-angle-right"></i>
          </nuxt-link>
          <h4 class="m-0 fw-bold">
            <i class="icon icon-regular-shield-exclamation ms-2"></i>{{ t('policy_page.title') }}
          </h4>
          <div style="width: 24px"></div>
        </div>
      </div>
    </header>

    <!-- Main Content -->
    <main class="container-fluid pt-4 pb-5 mb-5">
      <!-- Intro Section -->
      <section class="policy-hero rounded-4 p-4 mb-4">
        <p class="lead mb-0">{{ t('policy_page.intro') }}</p>
      </section>

      <!-- Privacy Sections -->
      <div class="privacy-sections">
        <!-- Information Collection -->
        <div class="privacy-card bg-white p-4 mb-4 rounded-3 shadow-sm">
          <h6 class="fw-bold text-default mb-3">
            <i class="icon icon-regular-database ms-2 text-default fs-4"></i>{{ t('policy_page.info_collection.title') }}
          </h6>
          <ul class="list-group list-group-flush">
            <li class="list-group-item d-flex align-items-start border-0 py-2">
              <i class="fas fa-network-wired text-muted mt-1 me-2"></i>
              <div>
                <strong>{{ t('policy_page.info_collection.ip_title') }}</strong>
                {{ t('policy_page.info_collection.ip_text') }}
              </div>
            </li>
            <li class="list-group-item d-flex align-items-start border-0 py-2">
              <i class="fas fa-money-bill-wave text-muted mt-1 me-2"></i>
              <div>
                <strong>{{ t('policy_page.info_collection.financial_title') }}</strong>
                {{ t('policy_page.info_collection.financial_text') }}
              </div>
            </li>
            <li class="list-group-item d-flex align-items-start border-0 py-2">
              <i class="fas fa-address-book text-muted mt-1 me-2"></i>
              <div>
                <strong>{{ t('policy_page.info_collection.contact_title') }}</strong>
                {{ t('policy_page.info_collection.contact_text') }}
              </div>
            </li>
          </ul>
        </div>

        <!-- Data Usage -->
        <div class="privacy-card bg-white p-4 mb-4 rounded-3 shadow-sm">
          <h6 class="fw-bold text-default mb-3">
            <i class="icon icon-regular-chart-bar-alt ms-2 text-default fs-4"></i>{{ t('policy_page.data_usage.title') }}
          </h6>
          <div class="usage-items">
            <div class="d-flex align-items-start mb-2" v-for="(item, index) in dataUsage" :key="index">
              <span class="badge bg-default text-dark ms-3">{{ index + 1 }}</span>
              <p class="mb-0">{{ t(item) }}</p>
            </div>
          </div>
        </div>

        <!-- Other Sections -->
        <div class="privacy-card bg-white p-4 mb-4 rounded-3 shadow-sm" v-for="(section, index) in otherSections" :key="index">
          <h6 class="fw-bold text-default mb-3">
            <i :class="section.icon + '  ms-2 text-default fs-4'"></i>{{ t(section.title) }}
          </h6>
          <p>{{ t(section.content) }}</p>
        </div>
      </div>
    </main>
  </div>
</template>

<script setup>
import { useI18n } from 'vue-i18n';
const { t, locale } = useI18n();
definePageMeta({
  layout: "web"
});

const dataUsage = ref([
  "policy_page.data_usage.items.improve_experience",
  "policy_page.data_usage.items.communication",
  "policy_page.data_usage.items.analysis"
]);

const otherSections = ref([
  {
    title: "policy_page.other_sections.marketing.title",
    icon: "icon icon-regular-crown-alt",
    content: "policy_page.other_sections.marketing.text"
  },
  {
    title: "policy_page.other_sections.security.title",
    icon: "icon icon-regular-lock",
    content: "policy_page.other_sections.security.text"
  },
  {
    title: "policy_page.other_sections.changes.title",
    icon: "icon icon-regular-coin",
    content: "policy_page.other_sections.changes.text"
  }
]);
</script>


<style scoped>
/* استفاده از استایل‌های یکپارچه با صفحات قبلی */
.policy-hero {
  background: rgba(255, 152, 0, 0.1);
  border: 1px solid rgba(255, 152, 0, 0.2);
}

.privacy-card {
  transition: all 0.3s ease;
  border-left: 3px solid #ff9800;
}

.privacy-card:hover {
  transform: translateY(-3px);
  box-shadow: 0 8px 20px rgba(255, 152, 0, 0.1);
}

.list-group-item {
  background-color: transparent;
}

/* استفاده از کلاس‌های Bootstrap برای کاهش CSS اختصاصی */
</style>